@@ -54,7 +54,7 @@ class system_information(base_extension):
 			(u'pygame', u'pygame', u'__version__'),
 			(u'pygaze', u'pygaze', u'__version__'),
 			(u'pyglet', u'pyglet', u'version'),
-			(u'PyQt', u'qtpy', u'__version__'),
+			(u'PyQt', u'qtpy', [u'QtCore', u'PYQT_VERSION_STR']),
 			(u'serial', u'serial', u'VERSION'),
 			(u'markdown', u'markdown', u'version'),
 			(u'bidi', u'bidi', u'VERSION'),
@@ -70,15 +70,30 @@ class system_information(base_extension):
 					u'%s [installed, but `%s` occured while importing]' \
 					% (name, e.__class__.__name__))
 				continue
-			if hasattr(mod, attr):
-				l.append(u'%s %s' % (name, getattr(mod, attr)))
+			if isinstance(attr, basestring):
+				attr = [attr]
+			while len(attr) > 1:
+				a = attr.pop(0)
+				if hasattr(mod, a):
+					mod = getattr(mod, a)
+			a = attr.pop(0)
+			if hasattr(mod, a):
+				l.append(u'%s %s' % (name, getattr(mod, a)))
 				continue
 			l.append(u'%s [version unknown]' % name)
-		with open(self.ext_resource(u'system-information.md')) as fd:
-			tmpl = fd.read()
-		md = tmpl % {
-			u'system' : platform.system(),
-			u'architecture' : platform.architecture()[0],
+		
+		# platform.architecture() does not seem to work correctly on Windows so a solution found on stackoverflow is used
+		# http://stackoverflow.com/questions/2208828/detect-64bit-os-windows-in-python
+		if(platform.platform().startswith('Windows') and platform.machine().endswith('64')):
+			t = 'win64'
+		elif(platform.platform().startswith('Windows') and not platform.machine().endswith('64')):
+			t = 'win32'
+		else:
+			t = platform.architecture()[0]
+			
+		md = safe_read(self.ext_resource(u'system-information.md')) % {
+			u'system' : platform.platform(),
+			u'architecture' : t,
 			u'modules' : u'- ' + u'\n- '.join(l)
 			}
 		self.tabwidget.open_markdown(md, icon=self.icon(),
